# Vendor Specific Utilization Tests

The Utilization tests ensure that the appropriate information is being gathered for pricing for a particular cloud vendor. It is centered around ensuring that the JSON generated by all agents is correct. Each JSON block is a test case, with potentially the following fields:

  - `testname`: The name of the test.
  - `uri`: The API endpoint for the cloud vendor. This contains a response indicating what the expected return from the API is for a given test. 
  - `expected_vendors_hash`: The vendor hash that should be generated by the agent based on the uri response.
  - `expected_metrics`: Supportability metrics that are either expected or unexpected in a given case. If the `call_count` is 0 it should be asserted that the Supportability metric was not sent.

As of [Metadata version 3](https://source.datanerd.us/agents/agent-specs/blob/c78cddeaa5fa23dce892b8c6da95b9f900636c35/Utilization.md) specs have been added for Azure, Google Cloud Platform, and Pivotal Cloud Foundry in addition to updates for AWS.